@@ -50,24 +50,6 @@
 #include "ifcmd.h"
 #include "functions.h"
 
-#ifdef NO_JOB_CONTROL
-BUILT_IN_COMMAND(execcmd)
-{ 
-	say("Your system does not support job control, sorry.");
-	return; 
-}
-int	get_child_exit (pid_t x)			{ return -1; }
-void	clean_up_processes (void)			{ return; }
-int	text_to_process (const char *x, const char *y, int z) 	
-{ 
-	say("Cannot send text to process without job control, sorry.");
-	return 1; 
-}
-void	add_process_wait (const char *, const char *y)	{ return; }
-int	is_valid_process (const char *x)		{ return -1; }
-BUILT_IN_FUNCTION(execctl) { RETURN_EMPTY; }
-#else
-
 #include <sys/wait.h>
 #include <sys/ioctl.h>
 #ifdef HAVE_SYS_FILIO_H
@@ -290,8 +272,8 @@ static void 	handle_filedesc (Process *proc, int *fd, int hook_nonl, int hook_nl
 	const char	*utf8_text;
 	char *extra = NULL;
 
-	/* No buffering! */
-	switch ((len = dgets(*fd, exec_buffer, IO_BUFFER_SIZE, 0))) 
+	/* 1 -> line buffering; used to be 0 -> No buffering */
+	switch ((len = dgets(*fd, exec_buffer, IO_BUFFER_SIZE, 1))) 
 	{
 	    case -1:		/* Something died */
 	    {
@@ -301,6 +283,12 @@ static void 	handle_filedesc (Process *proc, int *fd, int hook_nonl, int hook_nl
 		return;				/* PUNT! */
 	    }
 
+#if 1
+	    /* When buffering is 1 (line buffering), case 0 means "incomplete line" */
+	    case 0:
+		return;
+#else
+	    /* When buffering is 0 (no buffering), case 0 means "incomplete line" */
 	    case 0:		/* We didnt get a full line */
 	    {
 		/* 
@@ -329,6 +317,7 @@ static void 	handle_filedesc (Process *proc, int *fd, int hook_nonl, int hook_nl
 		*exec_buffer = 0;
 		FALLTHROUGH
 	    }
+#endif
 
 	    default:		/* We got a full line */
 	    {
@@ -1803,7 +1792,6 @@ char *  execctl (char *input)
 	char *	field;
 	Process *proc;
 	char *	retval = NULL;
-	size_t	clue = 0;
 
         GET_FUNC_ARG(listc, input);
         len = strlen(listc);
@@ -1814,7 +1802,7 @@ char *  execctl (char *input)
 
 		for (i = 0; i < process_list_size; i++)
 			if ((proc = process_list[i]))
-				malloc_strcat_word_c(&retval, space, proc->refnum_desc, DWORD_NO, &clue);
+				malloc_strcat_word(&retval, space, proc->refnum_desc, DWORD_NO);
 		RETURN_MSTR(retval);
         } else if (!my_strnicmp(listc, "NEW", len)) {
 		proc = new_process(input);
@@ -2021,5 +2009,3 @@ char *  execctl (char *input)
 	RETURN_EMPTY;
 }
 
-#endif
-
