@@ -40,19 +40,19 @@
 /*
  * irc_version is what $J returns, its the common-name for the version.
  */
-const char irc_version[] = "EPIC5-2.1.13";
-const char useful_info[] = "epic5 2 1 13";
+const char irc_version[] = "EPIC5-3.0.1";
+const char useful_info[] = "epic5 3 0 1";
 
 /*
  * internal_version is what $V returns, its the integer-id for the
  * version, and corresponds to the date of release, YYYYMMDD.
  */ 
-const char internal_version[] = "20240614";
+const char internal_version[] = "20241022";
 
 /*
  * In theory, this number is incremented for every commit.
  */
-const unsigned long	commit_id = 2125;
+const unsigned long	commit_id = 2143;
 
 /*
  * As a way to poke fun at the current rage of naming releases after
@@ -60,7 +60,7 @@ const unsigned long	commit_id = 2125;
  * reality, I have decided to start doing that with EPIC.  These names
  * are intentionally and maliciously silly.  Complaints will be ignored.
  */
-const char ridiculous_version_name[] = "Sockdolager";
+const char ridiculous_version_name[] = "Corrigendum";
 
 #define __need_putchar_x__
 #include "status.h"
@@ -1002,12 +1002,6 @@ static	int		level = 0,
 	caller[level] = NULL;
 	level--;
 
-#ifdef DELAYED_FREES
-	/* Reclaim any malloc()ed space */
-	if (level == 0 && need_delayed_free)
-		do_delayed_frees();
-#endif
-
 	if (level == 0)
 		check_message_from_queue(0);
 
@@ -1042,9 +1036,6 @@ int 	main (int argc, char *argv[])
 
 	create_utf8_locale();
 	setvbuf(stdout, NULL, _IOLBF, 1024);
-#ifdef SOCKS
-	SOCKSinit(argv[0]);
-#endif
         get_time(&start_time);
 
 	init_levels();
@@ -1067,7 +1058,6 @@ int 	main (int argc, char *argv[])
 	fprintf(stderr, "%s\n", compile_info);
 	fprintf(stderr, "OpenSSL version: %#8.8lx\n", OpenSSL_version_num());
 
-#ifndef NO_JOB_CONTROL
 	/* If we're a bot, do the bot thing. */
 	if (!use_input)
 	{
@@ -1088,7 +1078,6 @@ int 	main (int argc, char *argv[])
 		}
 	}
 	else
-#endif
 	{
 		fprintf(stderr, "Process [%d]", getpid());
 		if (isatty(0))
